var picu = picu || {};

picu.LightboxView = Backbone.View.extend({

    tagName: 'div',
    className: 'picu-lightbox',

    template: _.template( jQuery( "#picu-lightbox" ).html() ),

    initialize: function( number, collection, appstate, router ) {
        this.number = ( parseInt(number) - 1 );
        this.collection = collection;
        this.appstate = appstate;

        this.max = collection.length;
        this.router = router;
        this.current = ( parseInt(number) );

        // Get model from collection based on the number
        this.model = collection.models[this.number];

        // Render on change
        this.listenTo( this.model, 'change', this.render );

        // Key bindings
        _.bindAll( this , 'keyAction' );
        $( document ).on( 'keydown', this.keyAction);

    },

    render: function() {

        var lightboxTemplate = this.template( this.model.attributes );

        this.$el.html( lightboxTemplate );
        return this;
    },

    events: {
        'click .picu-lightbox-select': 'toggleImageSelection',
        'click .picu-lightbox-next': 'nextImage',
        'click .picu-lightbox-prev': 'previousImage',
        'keydown': 'keyAction'
    },

    nextImage: function( e ) {
        e.preventDefault();

        if ( this.current >= this.max ) {
            this.current = 1;
            this.router.navigate( '1', {trigger: true} );
        }
        else {
            this.current++;
            this.router.navigate( this.current.toString(), {trigger: true} );
        }
    },

    previousImage: function( e ) {
        e.preventDefault();

        if ( this.current <= 1 ) {
            this.current = this.max;
            this.router.navigate( this.current.toString(), {trigger: true} );
        }
        else {
            this.current--;
            this.router.navigate( this.current.toString() , {trigger: true} );
        }
    },

    toggleImageSelection: function() {
        picu.saveSelection( this );
    },
    
    keyAction: function( e ) {

        // ESC key
        if ( e.keyCode == 27 ) {
            e.preventDefault();
            this.router.navigate('index', {trigger: true} );
        }
        // left arrow key
        if ( e.keyCode == 37 ) {
            e.preventDefault();
            this.previousImage( e );
        }
        // right arrow key
        if ( e.keyCode == 39 ) {
            e.preventDefault();
            this.nextImage( e );
        }
        // enter, p or space key
        if ( 'approved' != this.appstate.get( 'poststatus' ) ) {
            if ( e.keyCode == 13 || e.keyCode == 80 || e.keyCode == 32 ) {
                e.preventDefault();
                this.toggleImageSelection();
            }
        }
    },

    remove: function() {
        // Unbind keydown
        $( document ).off( 'keydown', this.keyAction );
    }

});